# xsamtools
Lightly-modified versions of [htslib](https://github.com/samtools/htslib)
and [bcftools](https://github.com/samtools/bcftools), available through pypi packaging, with capability to merge VCF
streams.

# installation
```
pip install xsamtools
```
A C toolchain is required to install xsamtools.
